@@ -1,4 +1,4 @@
-package Algorithm::CheckDigits::M10_008;
+package Algorithm::CheckDigits::M11_013;
 
 use 5.006;
 use strict;
@@ -24,8 +24,6 @@ our @EXPORT_OK = ( 'new', @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = ();
 
-my @weight = ( 1,3,1,7,3,9,1 );
-
 sub new {
 	my $proto = shift;
 	my $type  = shift;
@@ -37,53 +35,51 @@ sub new {
 
 sub is_valid {
 	my ($self,$number) = @_;
-	if ($number =~ /^(\d{6})(\d)$/) {
-		return $2 == $self->_compute_checkdigit($1);
+	if ($number =~ /^([0-9]+)(\d)$/) {
+		return $2 == $self->_compute_checkdigits($1);
 	}
 	return ''
 } # is_valid()
 
 sub complete {
 	my ($self,$number) = @_;
-	if ($number =~ /^\d{6}$/) {
-		return  $number . $self->_compute_checkdigit($number);
+	if ($number =~ /^([0-9]+)$/
+	   and (my $cd = $self->_compute_checkdigits($1)) ne '') {
+		return $1 . $cd;
 	}
 	return '';
 } # complete()
 
 sub basenumber {
 	my ($self,$number) = @_;
-	if ($number =~ /^(\d{6})(\d)$/) {
-		return $1 if ($2 == $self->_compute_checkdigit($1));
+	if ($number =~ /^([0-9]+)(\d)$/) {
+		return $1 if ($2 == $self->_compute_checkdigits($1));
 	}
 	return '';
 } # basenumber()
 
 sub checkdigit {
 	my ($self,$number) = @_;
-	if ($number =~ /^(\d{6})(\d)$/) {
-		return $2 if ($2 == $self->_compute_checkdigit($1));
+	if ($number =~ /^([0-9]+)(\d)$/) {
+		return $2 if ($2 == $self->_compute_checkdigits($1));
 	}
 	return '';
 } # checkdigit()
 
-sub _compute_checkdigit {
+sub _compute_checkdigits {
 	my $self   = shift;
 	my $number = shift;
 
-	if ($number =~ /^\d{6}$/) {
+	$number =~ s/\.//g;
 
-		my @digits = split(//,$number);
-		my $sum    = 0;
-
-		for (my $i = 0; $i <= $#digits; $i++) {
-
-			$sum += $weight[$i] * $digits[$i];
-
-		}
-		return (10 - ($sum % 10) % 10);
+	my @digits = split(//,$number);
+	my $len = scalar(@digits);
+	my $sum = 0;
+	for (my $i = $#digits; $i >= 0; $i--) {
+		$sum += 2 ** ($len - $i) * $digits[$i];
 	}
-	return -1;
+	$sum %= 11;
+	return ($sum > 9) ? 0 : $sum;
 } # _compute_checkdigit()
 
 # Preloaded methods go here.
@@ -93,26 +89,26 @@ __END__
 
 =head1 NAME
 
-CheckDigits::M10_008 - compute check digits for Sedol (GB)
+CheckDigits::M11_013 - compute check digits for VAT Registration Number (GR)
 
 =head1 SYNOPSIS
 
   use CheckDigits;
 
-  $sedol = CheckDigits('sedol');
+  $ustid = CheckDigits('ustid_gr');
 
-  if ($sedol->is_valid('0123457')) {
+  if ($ustid->is_valid('123456783')) {
 	# do something
   }
 
-  $cn = $sedol->complete('012345');
-  # $cn = '0123457'
+  $cn = $ustid->complete('12345678');
+  # $cn = '123456783'
 
-  $cd = $sedol->checkdigit('0123457');
-  # $cd = '7'
+  $cd = $ustid->checkdigit('123456783');
+  # $cd = '3'
 
-  $bn = $sedol->basenumber('0123457');
-  # $bn = '012345'
+  $bn = $ustid->basenumber('123456783');
+  # $bn = '12345678';
   
 =head1 DESCRIPTION
 
@@ -122,17 +118,22 @@ CheckDigits::M10_008 - compute check digits for Sedol (GB)
 
 =item 1
 
-Beginning left all numbers are weighted with 1,3,1,7,3,9 and 1
-(checkdigit)
+Beginning right with the digit before the checkdigit all digits are
+weighted with 2 ** position. I. e. the last digit is
+multiplied with 2, the next with 4, then 8 and so on.
 
 =item 2
 
-The sum of all products is computed.
+The weighted digits are added.
 
 =item 3
 
-The check digit is the difference of the sum from step 3 to the next
-multiple of 10.
+The sum from step 2 is taken modulo 11.
+
+=item 4
+
+If the sum from step 3 is greater than 9, the check sum is 0 else it
+is the sum itself.
 
 =back
 
@@ -142,18 +143,19 @@ multiple of 10.
 
 =item is_valid($number)
 
-Returns true only if C<$number> consists solely of numbers and the last digit
-is a valid check digit according to the algorithm given above.
+Returns true only if C<$number> consists solely of numbers and hyphens
+and the two digits in the middle
+are valid check digits according to the algorithm given above.
 
 Returns false otherwise,
 
 =item complete($number)
 
-The check digit for C<$number> is computed and concatenated to the end
-of C<$number>.
+The check digit for C<$number> is computed and inserted into the
+middle of C<$number>.
 
 Returns the complete number with check digit or '' if C<$number>
-does not consist solely of digits and spaces.
+does not consist solely of digits, hyphens and spaces.
 
 =item basenumber($number)
 
@@ -164,8 +166,8 @@ Return '' otherwise.
 
 =item checkdigit($number)
 
-Returns the checkdigit of C<$number> if C<$number> has a valid check
-digit.
+Returns the check digits of C<$number> if C<$number> has valid check
+digits.
 
 Return '' otherwise.
 
@@ -183,6 +185,6 @@ Mathias Weidner, E<lt>mathias@weidner.in-bad-schmiedeberg.deE<gt>
 
 L<perl>,
 L<CheckDigits>,
-F<www.pruefziffernberechnung.de>.
+F<www.pruefziffernberechnung.de>,
 
 =cut
